==> javascript-frontend-2.8-sources.jar: org/sonar/javascript/tree/symbols/type/ArrayType.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011 SonarSource and Eriks Nukis
 * sonarqube@googlegroups.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.javascript.tree.symbols.type;

import org.sonar.plugins.javascript.api.symbols.Type;

import javax.annotation.Nullable;

public class ArrayType extends ObjectType {

  private Type elementType = null;

  @Override
  public Kind kind() {
    return Kind.ARRAY;
  }

  @Override
  public Callability callability() {
    return Callability.NON_CALLABLE;
  }

  public static ArrayType create(Type elementType){
    ArrayType type = new ArrayType();
    type.elementType = elementType;
    return type;
  }

  public static ArrayType create(){
    return new ArrayType();
  }

  @Nullable
  public Type elementType(){
    return elementType;
  }
}

==> javascript-frontend-2.18.0.3454-sources.jar: org/sonar/javascript/tree/symbols/type/ArrayType.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.javascript.tree.symbols.type;

import javax.annotation.Nullable;
import org.sonar.plugins.javascript.api.symbols.Type;

public class ArrayType extends ObjectType {

  private Type elementType = null;

  protected ArrayType() {
    super(Callability.NON_CALLABLE);
  }

  @Override
  public Kind kind() {
    return Kind.ARRAY;
  }

  public static ArrayType create(Type elementType) {
    ArrayType type = new ArrayType();
    type.elementType = elementType;
    return type;
  }

  public static ArrayType create() {
    return new ArrayType();
  }

  @Nullable
  public Type elementType() {
    return elementType;
  }
}
